@@ -7,8 +7,11 @@ KW_NFB = 'nbf'
 KW_IAT = 'iat'
 KW_TYPE = 'type'
 
+KW_JWT_ALGORITHM = 'JWT_ALGORITHM'
 KW_JWT_SECRET_KEY = 'JWT_SECRET_KEY'
 KW_JWT_BLACKLIST_ENABLED = 'JWT_BLACKLIST_ENABLED'
+KW_JWT_HEADER_NAME = 'JWT_HEADER_NAME'
+KW_JWT_HEADER_TYPE = 'JWT_HEADER_TYPE'
 
 UNAUTHORIZED_MESSAGE = 'Unauthorized'
 FORBIDDEN_MESSAGE = 'Frobidden'
@@ -21,8 +24,6 @@ ACCESS_VALUE_TYPE = 'access'
 REFRESH_VALUE_TYPE = 'refresh'
 
 
-JWT_HEADER_NAME = 'JWT_HEADER_NAME'
-JWT_HEADER_TYPE = 'JWT_HEADER_TYPE'
 DEFAULT_JWT_SECURITY_ALGORITHM = "HS256" ###- HS512
 DEFAULT_JWT_AUTHORIZATION_HEADER_NAME = "Authorization"
 DEFAULT_JWT_AUTHORIZATION_HEADER_TYPE = "Bearer"
