@@ -178,7 +178,7 @@ def muteLogs(api) :
     werkzeug_logger = logging.getLogger('werkzeug')
     werkzeug_logger.disabled = True
     api.app.logger.disabled = True
-    apschedulerLoggerEnabled = api.globals.getApiSetting(ConfigurationKeyConstant.SCHEDULER_ENABLE_KEY)
+    apschedulerLoggerEnabled = api.globals.getApiSetting(ConfigurationKeyConstant.API_SCHEDULER_ENABLE)
     apscheduler_logger = logging.getLogger('apscheduler.scheduler')
     default_apscheduler_logger = logging.getLogger('apscheduler.executors.default')
     apscheduler_logger.disabled = True if ObjectHelper.isNone(apschedulerLoggerEnabled) else not apschedulerLoggerEnabled
